Package: MSstatsResponse
Type: Package
Title: Statistical Methods for Chemoproteomics Dose-Response Analysis
Version: 1.2.0
Authors@R: c(
    person(
      "Sarah", "Szvetecz",
      email = "szvetecz.s@northeastern.edu",
      role = c("aut", "cre")), 
    person(
      "Tony", "Wu",
      email = "wu.anton@northeastern.edu",
      role = c("aut")),
    person(
      "Devon", "Kohler",
      email = "kohler.d@northeastern.edu",
      role = c("aut")),
    person(
      "Olga", "Vitek",
      email = "o.vitek@northeastern.edu",
      role = c("aut")))
Description: Tools for detecting drug-protein interactions and estimating IC50 
    values from chemoproteomics data. Implements semi-parametric isotonic regression, 
    bootstrapping, and curve fitting to evaluate compound effects on protein abundance.
URL: https://github.com/Vitek-Lab/MSstatsResponse
BugReports: https://github.com/Vitek-Lab/MSstatsResponse/issues
License: Artistic-2.0
Encoding: UTF-8
Depends: R (>= 4.5.0)
LazyData: false
RoxygenNote: 7.3.3
Imports: BiocParallel, ggplot2, dplyr, stats, parallel, data.table,
        tidyr, stringr, plotly, utils
Suggests: MSstats, MSstatsTMT, tidyverse, boot, purrr, gridExtra,
        knitr, rmarkdown, BiocStyle, testthat
VignetteBuilder: knitr
Roxygen: list(markdown = TRUE)
biocViews: Proteomics, MassSpectrometry, StatisticalMethod, Software,
        Regression
git_url: https://git.bioconductor.org/packages/MSstatsResponse
git_branch: RELEASE_3_23
git_last_commit: dcf6958
git_last_commit_date: 2026-04-28
Repository: Bioconductor 3.23
Date/Publication: 2026-04-28
NeedsCompilation: no
Packaged: 2026-04-28 22:56:53 UTC; biocbuild
Author: Sarah Szvetecz [aut, cre],
  Tony Wu [aut],
  Devon Kohler [aut],
  Olga Vitek [aut]
Maintainer: Sarah Szvetecz <szvetecz.s@northeastern.edu>
Built: R 4.6.0; ; 2026-04-29 04:52:07 UTC; unix
