% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/ExperimentalDesignSimulation.R
\name{plotHitRateMSstatsResponse}
\alias{plotHitRateMSstatsResponse}
\title{Plot hit rates by category}
\usage{
plotHitRateMSstatsResponse(results, rep_count, concentration_count)
}
\arguments{
\item{results}{Output of interaction test from doseResponseFit()}

\item{rep_count}{Number of replicates per concentration in simulation}

\item{concentration_count}{Number of concentrations in simulation}
}
\value{
A list containing the plot and plot data
}
\description{
Plot hit rates by category
}
