% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/ExperimentalDesignSimulation.R
\name{.extractTemplatesFromData}
\alias{.extractTemplatesFromData}
\title{Helper function to extract template profiles from user data}
\usage{
.extractTemplatesFromData(
  data,
  strong_proteins,
  weak_proteins,
  no_interaction_proteins,
  drug_name,
  concentrations
)
}
\arguments{
\item{data}{Prepared dose-response data}

\item{strong_proteins}{Vector of protein IDs for strong responders}

\item{weak_proteins}{Vector of protein IDs for weak responders}

\item{no_interaction_proteins}{Vector of protein IDs for non-responders}

\item{drug_name}{Drug to extract templates for}

\item{concentrations}{Concentrations to include in template (in nM)}
}
\value{
List with template data for each interaction type
}
\description{
Helper function to extract template profiles from user data
}
